@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005-2006, Jari Sundell
+// Copyright (C) 2005-2007, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -50,10 +50,10 @@
 #include "display/manager.h"
 #include "input/manager.h"
 #include "input/input_event.h"
+#include "rpc/command_scheduler.h"
+#include "rpc/parse_commands.h"
+#include "rpc/scgi.h"
 #include "ui/root.h"
-#include "utils/variable_map.h"
-
-#include "command_scheduler.h"
 
 #include "control.h"
 
@@ -66,9 +66,9 @@ Control::Control() :
   m_input(new input::Manager()),
   m_inputStdin(new input::InputEvent(STDIN_FILENO)),
 
-  m_commandScheduler(new CommandScheduler()),
-  m_variables(new utils::VariableMap()),
-  m_downloadVariables(new utils::VariableMap()),
+  m_commandScheduler(new rpc::CommandScheduler()),
+
+  m_scgi(NULL),
 
   m_tick(0) {
 
@@ -80,8 +80,7 @@ Control::Control() :
 
   m_taskShutdown.set_slot(rak::mem_fn(this, &Control::handle_shutdown));
 
-  m_commandScheduler->set_slot_command(rak::mem_fn(m_variables, &utils::VariableMap::process_std_single));
-  m_commandScheduler->set_slot_error_message(rak::mem_fn(m_core, &core::Manager::push_log));
+  m_commandScheduler->set_slot_error_message(rak::mem_fn(m_core, &core::Manager::push_log_std));
 }
 
 Control::~Control() {
@@ -89,8 +88,6 @@ Control::~Control() {
   delete m_input;
 
   delete m_commandScheduler;
-  delete m_variables;
-  delete m_downloadVariables;
 
   delete m_viewManager;
 
@@ -111,7 +108,7 @@ Control::initialize() {
 
   m_core->initialize_second();
   m_core->listen_open();
-  m_core->download_store()->enable(m_variables->get_value("session_lock"));
+  m_core->download_store()->enable(rpc::call_command_value("get_session_lock"));
 
   m_core->set_hashing_view(*m_viewManager->find_throw("hashing"));
   m_scheduler->set_view(*m_viewManager->find_throw("scheduler"));
@@ -123,6 +120,9 @@ Control::initialize() {
 
 void
 Control::cleanup() {
+  delete m_scgi;    m_scgi = NULL;
+  rpc::xmlrpc.cleanup();
+
   priority_queue_erase(&taskScheduler, &m_taskShutdown);
 
   m_inputStdin->remove(m_core->get_poll_manager()->get_torrent_poll());
@@ -155,6 +155,11 @@ Control::handle_shutdown() {
   m_shutdownReceived = false;
 }
 
+torrent::Poll*
+Control::poll() {
+  return m_core->get_poll_manager()->get_torrent_poll();
+}
+
 void
 Control::set_umask(mode_t m) {
   ::umask(m);
