@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005-2006, Jari Sundell
+// Copyright (C) 2005-2007, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -62,12 +62,13 @@ namespace input {
   class Manager;
 }  
 
-namespace utils {
-  class VariableMap;
+namespace rpc {
+  class CommandScheduler;
+  class FastCgi;
+  class SCgi;
+  class XmlRpc;
 }
 
-class CommandScheduler;
-
 class Control {
 public:
   Control();
@@ -89,15 +90,17 @@ public:
   core::ViewManager*  view_manager()                { return m_viewManager; }
   core::Scheduler*    scheduler()                   { return m_scheduler; }
 
+  torrent::Poll*      poll();
+
   ui::Root*           ui()                          { return m_ui; }
   display::Manager*   display()                     { return m_display; }
   input::Manager*     input()                       { return m_input; }
   input::InputEvent*  input_stdin()                 { return m_inputStdin; }
 
-  CommandScheduler*   command_scheduler()           { return m_commandScheduler; }
+  rpc::CommandScheduler* command_scheduler()        { return m_commandScheduler; }
 
-  utils::VariableMap* variable()                    { return m_variables; }
-  utils::VariableMap* download_variables()          { return m_downloadVariables; }
+  rpc::SCgi*          scgi()                        { return m_scgi; }
+  void                set_scgi(rpc::SCgi* f)        { m_scgi = f; }
 
   uint64_t            tick() const                  { return m_tick; }
   void                inc_tick()                    { m_tick++; }
@@ -124,9 +127,9 @@ private:
   input::Manager*     m_input;
   input::InputEvent*  m_inputStdin;
 
-  CommandScheduler*   m_commandScheduler;
-  utils::VariableMap* m_variables;
-  utils::VariableMap* m_downloadVariables;
+  rpc::CommandScheduler* m_commandScheduler;
+
+  rpc::SCgi*          m_scgi;
 
   uint64_t            m_tick;
 
