@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005-2006, Jari Sundell
+// Copyright (C) 2005-2007, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -48,8 +48,7 @@
 #include <torrent/tracker_list.h>
 #include <torrent/data/file_list.h>
 
-#include "utils/variable_generic.h"
-#include "utils/variable_map.h"
+#include "rpc/parse_commands.h"
 
 #include "control.h"
 #include "download.h"
@@ -126,59 +125,6 @@ Download::receive_storage_error(std::string msg) {
   m_message = "Storage error: [" + msg + "]";
 }
 
-Download::download_type::ConnectionType
-Download::string_to_connection_type(const std::string& name) {
-  // Return default if the name isn't found.
-  if (name == "leech")
-    return download_type::CONNECTION_LEECH;
-  else if (name == "seed")
-    return download_type::CONNECTION_SEED;
-  else
-    throw torrent::input_error("Unknown peer connection type selected: \"" + name + "\"");
-}
-
-const char*
-Download::connection_type_to_string(download_type::ConnectionType t) {
-  switch (t) {
-  case download_type::CONNECTION_LEECH:
-    return "leech";
-  case download_type::CONNECTION_SEED:
-    return "seed";
-  default:
-    return "unknown";
-  }
-}
-
-uint32_t
-Download::string_to_priority(const std::string& name) {
-  if (name == "off")
-    return 0;
-  else if (name == "low")
-    return 1;
-  else if (name == "normal")
-    return 2;
-  else if (name == "high")
-    return 3;
-  else
-    throw torrent::input_error("Could not convert string to priority.");
-}
-
-const char*
-Download::priority_to_string(uint32_t p) {
-  switch (p) {
-  case 0:
-    return "off";
-  case 1:
-    return "low";
-  case 2:
-    return "normal";
-  case 3:
-    return "high";
-  default:
-    throw torrent::input_error("Priority out of range.");
-  }
-}
-
 float
 Download::distributed_copies() const {
   const uint8_t* avail = m_download.chunks_seen();
@@ -206,28 +152,20 @@ Download::receive_chunk_failed(__UNUSED uint32_t idx) {
   m_chunksFailed++;
 }
 
-int64_t            Download::get_value(const char* key)                            { return control->download_variables()->get_d_value(this, key); }
-const std::string& Download::get_string(const char* key)                           { return control->download_variables()->get_d_string(this, key); }
-int64_t            Download::get_std_value(const std::string& key)                 { return control->download_variables()->get_d_value(this, key.c_str()); }
-const std::string& Download::get_std_string(const std::string& key)                { return control->download_variables()->get_d_string(this, key.c_str()); }
-void               Download::set(const char* key, const torrent::Object& value)    { return control->download_variables()->set_d(this, key, value); }
-void               Download::set_value(const char* key, int64_t value)             { return control->download_variables()->set_d_value(this, key, value); }
-void               Download::set_string(const char* key, const std::string& value) { return control->download_variables()->set_d_string(this, key, value); }
-
 // Clean up.
 void
 Download::set_root_directory(const std::string& path) {
   torrent::FileList* fileList = m_download.file_list();
 
   if (path.empty()) {
-    fileList->set_root_dir("./" + (fileList->size_files() > 1 ? m_download.name() : std::string()));
+    fileList->set_root_dir("./" + (fileList->is_multi_file() ? m_download.name() : std::string()));
 
   } else {
     std::string fullPath = rak::path_expand(path);
 
     fileList->set_root_dir(fullPath +
                            (*fullPath.rbegin() != '/' ? "/" : "") +
-                           (fileList->size_files() > 1 ? m_download.name() : ""));
+                           (fileList->is_multi_file() ? m_download.name() : std::string()));
   }
 
   bencode()->get_key("rtorrent").insert_key("directory", path);
