@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005-2006, Jari Sundell
+// Copyright (C) 2005-2007, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -100,32 +100,10 @@ public:
   uint32_t            priority();
   void                set_priority(uint32_t p);
 
-  int64_t             get_value(const char* key);
-  const std::string&  get_string(const char* key);
-
-  int64_t             get_std_value(const std::string& key);
-  const std::string&  get_std_string(const std::string& key);
-
-  void                set(const char* key, const torrent::Object& value);
-
-  void                set_value(const char* key, int64_t value);
-  void                set_string(const char* key, const std::string& value);
-
   void                set_root_directory(const std::string& path);
 
   bool                operator == (const std::string& str) const;
 
-  void                set_connection_type(const std::string& t) { m_download.set_connection_type(string_to_connection_type(t)); }
-
-  static connection_type string_to_connection_type(const std::string& name);
-  static const char*     connection_type_to_string(connection_type t);
-
-  const char*         connection_current() const                    { return connection_type_to_string(m_download.connection_type()); }
-  void                set_connection_current(const std::string& t)  { return m_download.set_connection_type(string_to_connection_type(t.c_str())); }
-
-  static uint32_t     string_to_priority(const std::string& name);
-  static const char*  priority_to_string(uint32_t p);
-
   float               distributed_copies() const;
 
 private:
