@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005-2006, Jari Sundell
+// Copyright (C) 2005-2007, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -47,7 +47,7 @@
 #include <torrent/resume.h>
 #include <torrent/data/file_utils.h>
 
-#include "utils/variable_generic.h"
+#include "rpc/parse_commands.h"
 
 #include "curl_get.h"
 #include "control.h"
@@ -75,10 +75,10 @@ DownloadFactory::DownloadFactory(const std::string& uri, Manager* m) :
   m_taskLoad.set_slot(rak::mem_fn(this, &DownloadFactory::receive_load));
   m_taskCommit.set_slot(rak::mem_fn(this, &DownloadFactory::receive_commit));
 
-  m_variables.insert("connection_leech", new utils::VariableAny(control->variable()->get("connection_leech")));
-  m_variables.insert("connection_seed",  new utils::VariableAny(control->variable()->get("connection_seed")));
-  m_variables.insert("directory",        new utils::VariableAny(control->variable()->get("directory")));
-  m_variables.insert("tied_to_file",     new utils::VariableBool(false));
+  m_variables["connection_leech"] = rpc::call_command_void("get_connection_leech");
+  m_variables["connection_seed"]  = rpc::call_command_void("get_connection_seed");
+  m_variables["directory"]        = rpc::call_command_void("get_directory");
+  m_variables["tied_to_file"]     = torrent::Object((int64_t)false);
 }
 
 DownloadFactory::~DownloadFactory() {
@@ -104,7 +104,9 @@ DownloadFactory::receive_load() {
   if (m_stream)
     throw torrent::internal_error("DownloadFactory::load() called on an object with m_stream != NULL");
 
-  if (std::strncmp(m_uri.c_str(), "http://", 7) == 0) {
+  if (std::strncmp(m_uri.c_str(), "http://", 7) == 0 ||
+      std::strncmp(m_uri.c_str(), "https://", 8) == 0 ||
+      std::strncmp(m_uri.c_str(), "ftp://", 6) == 0) {
     // Http handling here.
     m_stream = new std::stringstream;
     HttpQueue::iterator itr = m_manager->http_queue()->insert(m_uri, m_stream);
@@ -112,7 +114,7 @@ DownloadFactory::receive_load() {
     (*itr)->signal_done().slots().push_front(sigc::mem_fun(*this, &DownloadFactory::receive_loaded));
     (*itr)->signal_failed().slots().push_front(sigc::mem_fun(*this, &DownloadFactory::receive_failed));
 
-    m_variables.set("tied_to_file", (int64_t)false);
+    m_variables["tied_to_file"] = (int64_t)false;
 
   } else {
     std::fstream* stream = new std::fstream(rak::path_expand(m_uri).c_str(), std::ios::in | std::ios::binary);
@@ -173,44 +175,44 @@ DownloadFactory::receive_success() {
   initialize_rtorrent(download, rtorrent);
 
   // Move to 'rtorrent'.
-  download->set("connection_leech", m_variables.get("connection_leech"));
-  download->set("connection_seed",  m_variables.get("connection_seed"));
+  rpc::call_command_d("d.set_connection_leech", download, m_variables["connection_leech"]);
+  rpc::call_command_d("d.set_connection_seed", download,  m_variables["connection_seed"]);
 
-  download->set("max_uploads",      control->variable()->get("max_uploads"));
-  download->set("min_peers",        control->variable()->get("min_peers"));
-  download->set("max_peers",        control->variable()->get("max_peers"));
-  download->set("tracker_numwant",  control->variable()->get("tracker_numwant"));
+  rpc::call_command_d("d.set_max_uploads", download,      rpc::call_command_void("get_max_uploads"));
+  rpc::call_command_d("d.set_min_peers", download,        rpc::call_command_void("get_min_peers"));
+  rpc::call_command_d("d.set_max_peers", download,        rpc::call_command_void("get_max_peers"));
+  rpc::call_command_d("d.set_tracker_numwant", download,  rpc::call_command_void("get_tracker_numwant"));
 
-  if (download->get_value("complete") != 0) {
-    if (control->variable()->get_value("min_peers_seed") >= 0)
-      download->set("min_peers", control->variable()->get("min_peers_seed"));
+  if (rpc::call_command_d_value("d.get_complete", download) != 0) {
+    if (rpc::call_command_value("get_min_peers_seed") >= 0)
+      rpc::call_command_d("d.set_min_peers", download, rpc::call_command_void("get_min_peers_seed"));
 
-    if (control->variable()->get_value("max_peers_seed") >= 0)
-      download->set("max_peers", control->variable()->get("max_peers_seed"));
+    if (rpc::call_command_value("get_max_peers_seed") >= 0)
+      rpc::call_command_d("d.set_max_peers", download, rpc::call_command_void("get_max_peers_seed"));
   }
 
-  if (!control->variable()->get_value("use_udp_trackers"))
+  if (!rpc::call_command_value("get_use_udp_trackers"))
     download->enable_udp_trackers(false);
 
-  if (control->variable()->get_value("max_file_size") > 0)
-    download->set("max_file_size", control->variable()->get("max_file_size"));
+  if (rpc::call_command_value("get_max_file_size") > 0)
+    rpc::call_command_d("d.set_max_file_size", download, rpc::call_command_void("get_max_file_size"));
 
   // Check first if we already have these values set in the session
   // torrent, so that it is safe to change the values.
   //
   // Need to also catch the exceptions.
-  if (control->variable()->get_value("split_file_size") >= 0)
+  if (rpc::call_command_value("get_split_file_size") >= 0)
     torrent::file_split_all(download->download()->file_list(),
-                            control->variable()->get_value("split_file_size"),
-                            control->variable()->get_string("split_suffix"));
+                            rpc::call_command_value("get_split_file_size"),
+                            rpc::call_command_string("split_suffix"));
 
   if (!rtorrent->has_key_string("directory"))
-    download->set("directory", m_variables.get("directory"));
+    rpc::call_command_d("d.set_directory", download, m_variables["directory"]);
   else
-    download->set("directory", rtorrent->get_key("directory"));
+    rpc::call_command_d("d.set_directory", download, rtorrent->get_key("directory"));
 
-  if (!m_session && m_variables.get("tied_to_file").as_value())
-    download->set("tied_to_file", m_uri);
+  if (!m_session && m_variables["tied_to_file"].as_value())
+    rpc::call_command_d("d.set_tied_to_file", download, m_uri);
 
   torrent::Object& resumeObject = root->has_key_map("libtorrent_resume")
     ? root->get_key("libtorrent_resume")
@@ -230,13 +232,40 @@ DownloadFactory::receive_success() {
     return;
   }
 
+  // Save the info-hash just in case the commands decide to delete it.
+  torrent::HashString infohash = download->download()->info_hash();
+
+  try {
+    std::for_each(m_commands.begin(), m_commands.end(), rak::bind1st(std::ptr_fun(&rpc::parse_command_d_multiple_std), download));
+
+    if (m_manager->download_list()->find(infohash) == m_manager->download_list()->end())
+      throw torrent::input_error("The newly created download was removed.");
+
+  } catch (torrent::input_error& e) {
+    std::string msg = "Command on torrent creation failed: " + std::string(e.what());
+
+    if (m_printLog) {
+      m_manager->get_log_important().push_front(msg);
+      m_manager->get_log_complete().push_front(msg);
+    }
+    
+    if (m_manager->download_list()->find(infohash) != m_manager->download_list()->end()) {
+      // Should stop it, mark it bad. Perhaps even delete it?
+      download->set_hash_failed(true);
+      download->set_message(msg);
+      //     m_manager->download_list()->erase(m_manager->download_list()->find(infohash.data()));
+    }
+
+    return m_slotFinished();
+  }
+
   // When a download scheduler is implemented, this is handled by the
   // above insertion into download list.
   if (m_session) {
     // This torrent was queued for hashing or hashing when the session
     // file was saved. Or it was in a started state.
-    if (download->get_value("hashing") != Download::variable_hashing_stopped ||
-        download->get_value("state") != 0)
+    if (rpc::call_command_d_value("d.get_hashing", download) != Download::variable_hashing_stopped ||
+        rpc::call_command_d_value("d.get_state", download) != 0)
       m_manager->download_list()->resume(download);
 
   } else {
@@ -285,9 +314,9 @@ DownloadFactory::initialize_rtorrent(Download* download, torrent::Object* rtorre
     rtorrent->insert_key("tied_to_file", std::string());
 
   if (rtorrent->has_key_value("priority"))
-    download->set("priority", rtorrent->get_key_value("priority") % 4);
+    rpc::call_command_d("d.set_priority", download, rtorrent->get_key_value("priority") % 4);
   else
-    download->set("priority", (int64_t)2);
+    rpc::call_command_d("d.set_priority", download, (int64_t)2);
 
   if (rtorrent->has_key_value("key")) {
     download->tracker_list()->set_key(rtorrent->get_key_value("key"));
