@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005-2006, Jari Sundell
+// Copyright (C) 2005-2007, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -44,8 +44,7 @@
 #include <iosfwd>
 #include <sigc++/slot.h>
 #include <rak/priority_queue_default.h>
-
-#include "utils/variable_map.h"
+#include <torrent/object.h>
 
 #include "http_queue.h"
 
@@ -56,6 +55,7 @@ class Manager;
 class DownloadFactory {
 public:
   typedef sigc::slot<void> Slot;
+  typedef std::vector<std::string> command_list_type;
 
   // Do not destroy this object while it is in a HttpQueue.
   DownloadFactory(const std::string& uri, Manager* m);
@@ -67,7 +67,8 @@ public:
   void                load();
   void                commit();
 
-  utils::VariableMap* variable()            { return &m_variables; }
+  command_list_type&         commands()     { return m_commands; }
+  torrent::Object::map_type& variables()    { return m_variables; }
 
   bool                get_session() const   { return m_session; }
   void                set_session(bool v)   { m_session = v; }
@@ -100,7 +101,8 @@ private:
   bool                m_start;
   bool                m_printLog;
 
-  utils::VariableMap  m_variables;
+  command_list_type         m_commands;
+  torrent::Object::map_type m_variables;
 
   Slot                m_slotFinished;
   rak::priority_item  m_taskLoad;
