@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005-2006, Jari Sundell
+// Copyright (C) 2005-2007, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -43,6 +43,10 @@
 #include <string>
 #include <sigc++/slot.h>
 
+namespace torrent {
+  class HashString;
+}
+
 namespace core {
 
 class Download;
@@ -78,12 +82,17 @@ public:
 
   void                session_save();
 
+  iterator            find(const torrent::HashString& hash);
+
+  iterator            find_hex(const char* hash);
+  Download*           find_hex_ptr(const char* hash);
+
   // Might move this to DownloadFactory.
   Download*           create(std::istream* str, bool printLog);
 
   iterator            insert(Download* d);
 
-  void                erase(Download* d);
+  void                erase_ptr(Download* d);
   iterator            erase(iterator itr);
 
   //void                save(Download* d);
