@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005-2006, Jari Sundell
+// Copyright (C) 2005-2007, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -55,7 +55,7 @@
 #include <torrent/resume.h>
 #include <torrent/tracker_list.h>
 
-#include "utils/variable_map.h"
+#include "rpc/parse_commands.h"
 
 #include "globals.h"
 #include "curl_get.h"
@@ -85,13 +85,13 @@ connect_signal_storage_log(Download* d, torrent::Download::slot_string_type s) {
 // Need a proper logging class for this.
 static void
 connect_signal_tracker_dump(Download* d, torrent::Download::slot_dump_type s) {
-  if (!control->variable()->get_string("tracker_dump").empty())
+  if (!rpc::call_command_string("get_tracker_dump").empty())
     d->download()->signal_tracker_dump(s);
 }
 
 static void
 receive_tracker_dump(const std::string& url, const char* data, size_t size) {
-  const std::string& filename = control->variable()->get_string("tracker_dump");
+  const std::string& filename = rpc::call_command_string("get_tracker_dump");
 
   if (filename.empty())
     return;
@@ -108,7 +108,7 @@ receive_tracker_dump(const std::string& url, const char* data, size_t size) {
 
 void
 Manager::handshake_log(const sockaddr* sa, int msg, int err, const torrent::HashString* hash) {
-  if (!control->variable()->get_value("handshake_log"))
+  if (!rpc::call_command_value("get_handshake_log"))
     return;
   
   std::string peer;
@@ -165,28 +165,16 @@ Manager::handshake_log(const sockaddr* sa, int msg, int err, const torrent::Hash
   }
 }
 
-// Hmm... find some better place for all this.
 void
-Manager::delete_tied(Download* download) {
-  const std::string& tie = download->get_string("tied_to_file");
-
-  // This should be configurable, need to wait for the variable
-  // thingie to be implemented.
-  if (tie.empty())
-    return;
-
-  if (::unlink(rak::path_expand(tie).c_str()) == -1)
-    push_log("Could not unlink tied file: " + std::string(rak::error_number::current().c_str()));
-
-  download->set("tied_to_file", std::string());
+Manager::push_log(const char* msg) {
+  m_logImportant.push_front(msg);
+  m_logComplete.push_front(msg);
 }
 
 Manager::Manager() :
   m_hashingView(NULL),
 
-  m_pollManager(NULL),
-  m_portFirst(6890),
-  m_portLast(6999) {
+  m_pollManager(NULL) {
 
   m_downloadStore = new DownloadStore();
   m_downloadList = new DownloadList();
@@ -242,7 +230,7 @@ Manager::initialize_second() {
   m_downloadList->slot_map_insert()["1_connect_storage_log"]  = sigc::bind(sigc::ptr_fun(&connect_signal_storage_log), sigc::mem_fun(m_logComplete, &Log::push_front));
   m_downloadList->slot_map_insert()["1_connect_tracker_dump"] = sigc::bind(sigc::ptr_fun(&connect_signal_tracker_dump), sigc::ptr_fun(&receive_tracker_dump));
 
-  m_downloadList->slot_map_erase()["9_delete_tied"] = sigc::mem_fun(this, &Manager::delete_tied);
+  m_downloadList->slot_map_erase()["9_delete_tied"] = sigc::bind<0>(&rpc::call_command_d_v_void, "d.delete_tied");
 
   torrent::connection_manager()->set_signal_handshake_log(sigc::mem_fun(this, &Manager::handshake_log));
 }
@@ -262,12 +250,6 @@ Manager::cleanup() {
 
 void
 Manager::shutdown(bool force) {
-  // This doesn't trigger a compiler error on gcc-3.4.5 for some reason.
-//   if (!force)
-//     std::for_each(m_downloadList->begin(), m_downloadList->end(), std::bind1st(std::mem_fun(&DownloadList::pause), &m_downloadList));
-//   else
-//     std::for_each(m_downloadList->begin(), m_downloadList->end(), std::bind1st(std::mem_fun(&DownloadList::close), &m_downloadList));
-
   if (!force)
     std::for_each(m_downloadList->begin(), m_downloadList->end(), std::bind1st(std::mem_fun(&DownloadList::pause), m_downloadList));
   else
@@ -276,25 +258,40 @@ Manager::shutdown(bool force) {
 
 void
 Manager::listen_open() {
-  if (!control->variable()->get_value("port_open"))
+  // This stuff really should be moved outside of manager, make it
+  // part of the init script.
+  if (!rpc::call_command_value("get_port_open"))
     return;
 
-  if (m_portFirst > m_portLast)
-    throw torrent::input_error("Invalid port range for listening");
+  int portFirst, portLast;
+  torrent::Object portRange = rpc::call_command_void("get_port_range");
 
-  if (control->variable()->get_value("port_random")) {
-    int boundary = m_portFirst + random() % (m_portLast - m_portFirst + 1);
+  if (portRange.is_string()) {
+    if (std::sscanf(portRange.as_string().c_str(), "%i-%i", &portFirst, &portLast) != 2)
+      throw torrent::input_error("Invalid port_range argument.");
+    
+//   } else if (portRange.is_list()) {
 
-    if (torrent::connection_manager()->listen_open(boundary, m_portLast) ||
-        torrent::connection_manager()->listen_open(m_portFirst, boundary))
+  } else {
+    throw torrent::input_error("Invalid port_range argument.");
+  }
+
+  if (portFirst > portLast || portLast >= (1 << 16))
+    throw torrent::input_error("Invalid port range.");
+
+  if (rpc::call_command_value("get_port_random")) {
+    int boundary = portFirst + random() % (portLast - portFirst + 1);
+
+    if (torrent::connection_manager()->listen_open(boundary, portLast) ||
+        torrent::connection_manager()->listen_open(portFirst, boundary))
       return;
 
   } else {
-    if (torrent::connection_manager()->listen_open(m_portFirst, m_portLast))
+    if (torrent::connection_manager()->listen_open(portFirst, portLast))
       return;
   }
 
-  throw torrent::input_error("Could not open/bind a port for listening: " + std::string(rak::error_number::current().c_str()));
+  throw torrent::input_error("Could not open/bind port for listening: " + std::string(rak::error_number::current().c_str()));
 }
 
 std::string
@@ -398,14 +395,15 @@ Manager::receive_http_failed(std::string msg) {
 }
 
 void
-Manager::try_create_download(const std::string& uri, bool start, bool printLog, bool tied) {
+Manager::try_create_download(const std::string& uri, int flags, const command_list_type& commands) {
   // Adding download.
   DownloadFactory* f = new DownloadFactory(uri, this);
 
-  f->variable()->set("tied_to_file", tied ? "yes" : "no");
+  f->variables()["tied_to_file"] = (int64_t)(bool)(flags & create_tied);
+  f->commands().insert(f->commands().end(), commands.begin(), commands.end());
 
-  f->set_start(start);
-  f->set_print_log(printLog);
+  f->set_start(flags & create_start);
+  f->set_print_log(!(flags & create_quiet));
   f->slot_finished(sigc::bind(sigc::ptr_fun(&rak::call_delete_func<core::DownloadFactory>), f));
   f->load();
   f->commit();
@@ -460,16 +458,21 @@ path_expand(std::vector<std::string>* paths, const std::string& pattern) {
   std::transform(currentCache.begin(), currentCache.end(), std::back_inserter(*paths), std::mem_fun_ref(&utils::Directory::get_path));
 }
 
+bool
+manager_equal_tied(const std::string& path, Download* download) {
+  return path == rpc::call_command_d_string("d.get_tied_to_file", download);
+}
+
 void
-Manager::try_create_download_expand(const std::string& uri, bool start, bool printLog, bool tied) {
+Manager::try_create_download_expand(const std::string& uri, int flags, command_list_type commands) {
   std::vector<std::string> paths;
   paths.reserve(256);
 
   path_expand(&paths, uri);
 
-  if (tied)
+  if (flags & create_tied)
     for (std::vector<std::string>::iterator itr = paths.begin(); itr != paths.end(); )
-      if (std::find_if(m_downloadList->begin(), m_downloadList->end(), rak::equal(*itr, rak::bind2nd(std::mem_fun(&Download::get_string), "tied_to_file")))
+      if (std::find_if(m_downloadList->begin(), m_downloadList->end(), rak::bind1st(std::ptr_fun(&manager_equal_tied), *itr))
           != m_downloadList->end())
         itr = paths.erase(itr);
       else
@@ -477,10 +480,10 @@ Manager::try_create_download_expand(const std::string& uri, bool start, bool pri
 
   if (!paths.empty())
     for (std::vector<std::string>::iterator itr = paths.begin(); itr != paths.end(); ++itr)
-      try_create_download(*itr, start, printLog, tied);
+      try_create_download(*itr, flags, commands);
 
   else
-    try_create_download(uri, start, printLog, tied);
+    try_create_download(uri, flags, commands);
 }
 
 // DownloadList's hashing related functions don't actually start the
@@ -501,7 +504,7 @@ Manager::receive_hashing_changed() {
       continue;
 
     bool tryQuick =
-      (*itr)->get_value("hashing") == Download::variable_hashing_initial &&
+      rpc::call_command_d_value("d.get_hashing", *itr) == Download::variable_hashing_initial &&
       (*itr)->download()->file_list()->bitfield()->empty();
 
     if (!tryQuick && foundHashing)
@@ -524,7 +527,7 @@ Manager::receive_hashing_changed() {
         (*itr)->download()->hash_stop();
 
         if (foundHashing) {
-          (*itr)->set_value("hashing", Download::variable_hashing_rehash);
+          rpc::call_command_d_set_value("d.set_hashing", *itr, Download::variable_hashing_rehash);
           continue;
         }
       }
@@ -535,7 +538,7 @@ Manager::receive_hashing_changed() {
     } catch (torrent::local_error& e) {
       if (tryQuick) {
         // Make sure we don't repeat the quick hashing.
-        (*itr)->set_value("hashing", Download::variable_hashing_rehash);
+        rpc::call_command_d_set_value("d.set_hashing", *itr, Download::variable_hashing_rehash);
 
       } else {
         (*itr)->set_hash_failed(true);
