@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005-2006, Jari Sundell
+// Copyright (C) 2005-2007, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -38,6 +38,7 @@
 #define RTORRENT_CORE_MANAGER_H
 
 #include <iosfwd>
+#include <vector>
 
 #include "download_list.h"
 #include "poll_manager.h"
@@ -51,6 +52,7 @@ namespace core {
 
 class DownloadStore;
 class HttpQueue;
+
 class View;
 
 class Manager {
@@ -74,8 +76,6 @@ public:
   Log&                get_log_important()                 { return m_logImportant; }
   Log&                get_log_complete()                  { return m_logComplete; }
 
-  void                set_port_range(int a, int b)        { m_portFirst = a; m_portLast = b; }
-
   // Really should find a more descriptive name.
   void                initialize_first();
   void                initialize_second();
@@ -94,15 +94,20 @@ public:
 
   void                shutdown(bool force);
 
-  void                push_log(const std::string& msg)    { m_logImportant.push_front(msg); m_logComplete.push_front(msg); }
+  void                push_log(const char* msg);
+  void                push_log_std(const std::string& msg) { m_logImportant.push_front(msg); m_logComplete.push_front(msg); }
 
   void                handshake_log(const sockaddr* sa, int msg, int err, const torrent::HashString* hash);
 
-  // Temporary, find a better place for this.
-  void                try_create_download(const std::string& uri, bool start, bool printLog = true, bool tied = false);
-  void                try_create_download_expand(const std::string& uri, bool start, bool printLog = true, bool tied = false);
+  static const int create_start = 0x1;
+  static const int create_tied  = 0x2;
+  static const int create_quiet = 0x4;
 
-  void                delete_tied(Download* d);
+  typedef std::vector<std::string> command_list_type;
+
+  // Temporary, find a better place for this.
+  void                try_create_download(const std::string& uri, int flags, const command_list_type& commands);
+  void                try_create_download_expand(const std::string& uri, int flags, command_list_type commands = command_list_type());
 
 private:
   void                create_http(const std::string& uri);
@@ -123,9 +128,6 @@ private:
   PollManager*        m_pollManager;
   Log                 m_logImportant;
   Log                 m_logComplete;
-
-  int                 m_portFirst;
-  int                 m_portLast;
 };
 
 }
