@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005-2006, Jari Sundell
+// Copyright (C) 2005-2007, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -52,6 +52,7 @@
 
 #include "core/download.h"
 #include "core/manager.h"
+#include "rpc/parse_commands.h"
 
 #include "control.h"
 #include "globals.h"
@@ -158,13 +159,13 @@ print_download_info(char* first, char* last, core::Download* d) {
     first = print_buffer(first, last, "                ");
   }
 
-  first = print_buffer(first, last, " [%c%c R: %3.2f",
-                       d->get_string("tied_to_file").empty() ? ' ' : 'T',
-                       d->get_value("ignore_commands") == 0 ? ' ' : 'I',
-                       d->download()->bytes_done() > 0 ? (double)(100 * d->download()->up_rate()->total() / d->download()->bytes_done()) / 100 : 0.0);
+  first = print_buffer(first, last, " [%c%c R: %4.2f",
+                       rpc::call_command_d_string("d.get_tied_to_file", d).empty() ? ' ' : 'T',
+                       rpc::call_command_d_value("d.get_ignore_commands", d) == 0 ? ' ' : 'I',
+                       (double)rpc::call_command_d_value("d.get_ratio", d) / 1000.0);
 
   if (d->priority() != 2)
-    first = print_buffer(first, last, " %s]", core::Download::priority_to_string(d->priority()));
+    first = print_buffer(first, last, " %s]", rpc::call_command_d_string("d.get_priority_str", d).c_str());
   else
     first = print_buffer(first, last, "]");
 
@@ -178,7 +179,7 @@ char*
 print_download_status(char* first, char* last, core::Download* d) {
   if (d->is_active())
     ;
-  else if (d->get_value("hashing") != 0)
+  else if (rpc::call_command_d_value("d.get_hashing", d) != 0)
     first = print_buffer(first, last, "Hashing: ");
   else if (!d->is_active())
     first = print_buffer(first, last, "Inactive: ");
