@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005-2006, Jari Sundell
+// Copyright (C) 2005-2007, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -58,19 +58,19 @@
 #include "display/manager.h"
 #include "input/bindings.h"
 
+#include "rpc/command_scheduler.h"
+#include "rpc/command_scheduler_item.h"
+#include "rpc/parse_commands.h"
 #include "utils/directory.h"
-#include "utils/variable_map.h"
 
 #include "control.h"
 #include "globals.h"
 #include "signal_handler.h"
-#include "option_handler_rules.h"
 #include "option_parser.h"
-#include "command_scheduler.h"
-#include "command_scheduler_item.h"
 
 void do_panic(int signum);
 void print_help();
+void initialize_commands();
 
 int
 parse_options(Control* c, int argc, char** argv) {
@@ -81,14 +81,14 @@ parse_options(Control* c, int argc, char** argv) {
     optionParser.insert_flag('h', sigc::ptr_fun(&print_help));
     optionParser.insert_flag('n', OptionParser::Slot());
 
-    optionParser.insert_option('b', sigc::bind<0>(sigc::mem_fun(c->variable(), &utils::VariableMap::set_string), "bind"));
-    optionParser.insert_option('d', sigc::bind<0>(sigc::mem_fun(c->variable(), &utils::VariableMap::set_string), "directory"));
-    optionParser.insert_option('i', sigc::bind<0>(sigc::mem_fun(c->variable(), &utils::VariableMap::set_string), "ip"));
-    optionParser.insert_option('p', sigc::bind<0>(sigc::mem_fun(c->variable(), &utils::VariableMap::set_string), "port_range"));
-    optionParser.insert_option('s', sigc::bind<0>(sigc::mem_fun(c->variable(), &utils::VariableMap::set_string), "session"));
+    optionParser.insert_option('b', sigc::bind<0>(sigc::ptr_fun(&rpc::call_command_set_string), "bind"));
+    optionParser.insert_option('d', sigc::bind<0>(sigc::ptr_fun(&rpc::call_command_set_string), "directory"));
+    optionParser.insert_option('i', sigc::bind<0>(sigc::ptr_fun(&rpc::call_command_set_string), "ip"));
+    optionParser.insert_option('p', sigc::bind<0>(sigc::ptr_fun(&rpc::call_command_set_string), "port_range"));
+    optionParser.insert_option('s', sigc::bind<0>(sigc::ptr_fun(&rpc::call_command_set_string), "session"));
 
-    optionParser.insert_option('O', sigc::mem_fun(c->variable(), &utils::VariableMap::process_std_single));
-    optionParser.insert_option_list('o', sigc::mem_fun(c->variable(), &utils::VariableMap::set_std_string));
+    optionParser.insert_option('O', sigc::ptr_fun(&rpc::parse_command_single_std));
+    optionParser.insert_option_list('o', sigc::ptr_fun(&rpc::call_command_set_std_string));
 
     return optionParser.process(argc, argv);
 
@@ -162,14 +162,13 @@ main(int argc, char** argv) {
     control->core()->initialize_first();
 
     // Initialize option handlers after libtorrent to ensure
-    // torrent::ConnectionManager* is valid etc.
-    initialize_variables();
-    initialize_download_variables();
+    // torrent::ConnectionManager* are valid etc.
+    initialize_commands();
 
-    control->variable()->process_multiple
-      (
+    rpc::parse_command_multiple(
        // Currently not doing any sorting on main.
        "view_add = main\n"
+       "view_add = default\n"
 
        "view_add = name\n"
        "view_sort_new = name,name\n"
@@ -221,6 +220,7 @@ main(int argc, char** argv) {
 
        //"schedule = scheduler,10,10,download_scheduler=\n"
        "schedule = session_save,1800,1800,session_save=\n"
+       "schedule = low_diskspace,5,60,close_low_diskspace=500M\n"
 
        // Changing these will bork the (non-existant) scheduler.
        "view_add = scheduler\n"
@@ -228,12 +228,12 @@ main(int argc, char** argv) {
        "view_sort_current = scheduler,state_changed\n"
 
        //    "schedule = scheduler,10,10,download_scheduler=\n"
-       );
+    );
 
     if (OptionParser::has_flag('n', argc, argv))
       control->core()->push_log("Ignoring ~/.rtorrent.rc.");
     else
-      control->variable()->process_single("try_import = ~/.rtorrent.rc");
+      rpc::parse_command_single("try_import = ~/.rtorrent.rc");
 
     int firstArg = parse_options(control, argc, argv);
 
@@ -271,7 +271,10 @@ main(int argc, char** argv) {
 
   } catch (std::exception& e) {
     display::Canvas::cleanup();
-    delete control;
+
+    // Safe to delete here? Seem to cause problems if cleanup hasn't
+    // been called.
+    //delete control;
 
     std::cout << "rtorrent: " << e.what() << std::endl;
     return -1;
