@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005-2006, Jari Sundell
+// Copyright (C) 2005-2007, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -56,7 +56,7 @@
 #include "display/window_log.h"
 #include "display/window_title.h"
 
-#include "utils/variable_map.h"
+#include "rpc/parse_commands.h"
 
 #include "control.h"
 #include "download.h"
@@ -232,7 +232,7 @@ DownloadList::receive_view_input(Input type) {
   case INPUT_CHANGE_DIRECTORY:
     title = "change_directory";
 
-    input->str() = control->variable()->get_string("directory");
+    input->str() = rpc::call_command_string("get_directory");
     input->set_pos(input->str().length());
 
     break;
@@ -278,19 +278,22 @@ DownloadList::receive_exit_input(Input type) {
 
     case INPUT_LOAD_DEFAULT:
     case INPUT_LOAD_MODIFIED:
-      control->core()->try_create_download_expand(input->str(), type == INPUT_LOAD_DEFAULT);
+      if (input->str().empty())
+        break;
+
+      control->core()->try_create_download_expand(input->str(), type == INPUT_LOAD_DEFAULT ? core::Manager::create_start : 0);
       break;
 
     case INPUT_CHANGE_DIRECTORY:
       if (current_view()->focus() == current_view()->end_visible())
         throw torrent::input_error("No download in focus to change root directory.");
 
-      (*current_view()->focus())->set("directory", rak::trim(input->str()));
-      control->core()->push_log("New root directory \"" + (*current_view()->focus())->get_string("directory") + "\" for torrent.");
+      rpc::call_command_d("d.set_directory", *current_view()->focus(), rak::trim(input->str()));
+      control->core()->push_log_std("New root directory \"" + rpc::call_command_d_string("d.get_directory", *current_view()->focus()) + "\" for torrent.");
       break;
 
     case INPUT_COMMAND:
-      control->variable()->process_std_single(input->str());
+      rpc::parse_command_d_single_std(current_view()->focus() != current_view()->end_visible() ? *current_view()->focus() : NULL, input->str());
       break;
 
     default:
