@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005-2006, Jari Sundell
+// Copyright (C) 2005-2007, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -47,6 +47,7 @@
 #include "display/frame.h"
 #include "display/manager.h"
 #include "input/manager.h"
+#include "rpc/parse_commands.h"
 
 #include "control.h"
 #include "element_download_list.h"
@@ -151,10 +152,10 @@ ElementDownloadList::receive_stop_download() {
   if (m_view->focus() == m_view->end_visible())
     return;
 
-  if ((*m_view->focus())->get_value("state") == 1)
+  if (rpc::call_command_d_value("d.get_state", *m_view->focus()) == 1)
     control->core()->download_list()->stop_normal(*m_view->focus());
   else
-    control->core()->download_list()->erase(*m_view->focus());
+    control->core()->download_list()->erase_ptr(*m_view->focus());
 
   m_view->set_last_changed();
 }
@@ -166,7 +167,7 @@ ElementDownloadList::receive_close_download() {
 
   core::Download* download = *m_view->focus();
 
-  download->set("ignore_commands", (int64_t)1);
+  rpc::call_command_d("d.set_ignore_commands", download, (int64_t)1);
 
   control->core()->download_list()->stop_normal(download);
   control->core()->download_list()->close(download);
@@ -205,11 +206,11 @@ ElementDownloadList::receive_ignore_ratio() {
   if (m_view->focus() == m_view->end_visible())
     return;
 
-  if ((*m_view->focus())->get_value("ignore_commands") != 0) {
-    (*m_view->focus())->set("ignore_commands", (int64_t)0);
+  if (rpc::call_command_d_value("d.get_ignore_commands", *m_view->focus()) != 0) {
+    rpc::call_command_d_set_value("d.set_ignore_commands", *m_view->focus(), (int64_t)0);
     control->core()->push_log("Torrent set to heed commands.");
   } else {
-    (*m_view->focus())->set("ignore_commands", (int64_t)1);
+    rpc::call_command_d_set_value("d.set_ignore_commands", *m_view->focus(), (int64_t)1);
     control->core()->push_log("Torrent set to ignore commands.");
   }
 }
@@ -219,13 +220,12 @@ ElementDownloadList::receive_clear_tied() {
   if (m_view->focus() == m_view->end_visible())
     return;
 
-  const std::string& tiedFile = (*m_view->focus())->get_string("tied_to_file");
+  const std::string& tiedFile = rpc::call_command_d_string("d.get_tied_to_file", *m_view->focus());
 
   if (!tiedFile.empty()) {
-    // Move this into core?
-    control->core()->delete_tied(*m_view->focus());
+    rpc::call_command_d_void("d.delete_tied", *m_view->focus());
 
-    control->core()->push_log("Cleared tied to file association for download.");
+    control->core()->push_log("Cleared tied to file association for the selected download.");
   }
 }
 
@@ -234,7 +234,7 @@ ElementDownloadList::receive_change_view(const std::string& name) {
   core::ViewManager::iterator itr = control->view_manager()->find(name);
 
   if (itr == control->view_manager()->end()) {
-    control->core()->push_log("Could not find view \"" + name + "\".");
+    control->core()->push_log_std("Could not find view \"" + name + "\".");
     return;
   }
 
