@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005-2006, Jari Sundell
+// Copyright (C) 2005-2007, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -49,7 +49,7 @@
 #include "display/window_statusbar.h"
 #include "input/manager.h"
 #include "input/text_input.h"
-#include "utils/variable_map.h"
+#include "rpc/parse_commands.h"
 
 #include "control.h"
 #include "download_list.h"
@@ -64,10 +64,7 @@ Root::Root() :
   m_windowTitle(NULL),
   m_windowHttpQueue(NULL),
   m_windowInput(NULL),
-  m_windowStatusbar(NULL),
-
-  m_maxUploadsGlobal(0),
-  m_maxDownloadsGlobal(0) {
+  m_windowStatusbar(NULL) {
 }
 
 void
@@ -126,19 +123,21 @@ void
 Root::setup_keys() {
   m_control->input()->push_back(&m_bindings);
 
-  if (strcasecmp(control->variable()->get_string("key_layout").c_str(), "azerty") == 0) {
+  const std::string& keyLayout = rpc::call_command_string("get_key_layout");
+
+  if (strcasecmp(keyLayout.c_str(), "azerty") == 0) {
     m_bindings['q']           = sigc::bind(sigc::mem_fun(*this, &Root::adjust_up_throttle), 1);
     m_bindings['w']           = sigc::bind(sigc::mem_fun(*this, &Root::adjust_up_throttle), -1);
     m_bindings['Q']           = sigc::bind(sigc::mem_fun(*this, &Root::adjust_down_throttle), 1);
     m_bindings['W']           = sigc::bind(sigc::mem_fun(*this, &Root::adjust_down_throttle), -1);
 
-  } else if (strcasecmp(control->variable()->get_string("key_layout").c_str(), "qwertz") == 0) {
+  } else if (strcasecmp(keyLayout.c_str(), "qwertz") == 0) {
     m_bindings['a']           = sigc::bind(sigc::mem_fun(*this, &Root::adjust_up_throttle), 1);
     m_bindings['y']           = sigc::bind(sigc::mem_fun(*this, &Root::adjust_up_throttle), -1);
     m_bindings['A']           = sigc::bind(sigc::mem_fun(*this, &Root::adjust_down_throttle), 1);
     m_bindings['Y']           = sigc::bind(sigc::mem_fun(*this, &Root::adjust_down_throttle), -1);
 
-  } else if (strcasecmp(control->variable()->get_string("key_layout").c_str(), "dvorak") == 0) {
+  } else if (strcasecmp(keyLayout.c_str(), "dvorak") == 0) {
     m_bindings['a']           = sigc::bind(sigc::mem_fun(*this, &Root::adjust_up_throttle), 1);
     m_bindings[';']           = sigc::bind(sigc::mem_fun(*this, &Root::adjust_up_throttle), -1);
     m_bindings['A']           = sigc::bind(sigc::mem_fun(*this, &Root::adjust_down_throttle), 1);
@@ -151,7 +150,7 @@ Root::setup_keys() {
     m_bindings['Z']           = sigc::bind(sigc::mem_fun(*this, &Root::adjust_down_throttle), -1);
   }
 
-  if (strcasecmp(control->variable()->get_string("key_layout").c_str(), "dvorak") != 0) {
+  if (strcasecmp(keyLayout.c_str(), "dvorak") != 0) {
     m_bindings['s']           = sigc::bind(sigc::mem_fun(*this, &Root::adjust_up_throttle), 5);
     m_bindings['x']           = sigc::bind(sigc::mem_fun(*this, &Root::adjust_up_throttle), -5);
     m_bindings['S']           = sigc::bind(sigc::mem_fun(*this, &Root::adjust_down_throttle), 5);
@@ -185,14 +184,15 @@ Root::set_down_throttle(unsigned int throttle) {
 
   torrent::set_down_throttle(throttle * 1024);
 
-  int64_t div = control->variable()->get_value("max_downloads_div");
+  unsigned int div    = std::max<int>(rpc::call_command_value("get_max_downloads_div"), 0);
+  unsigned int global = std::max<int>(rpc::call_command_value("get_max_downloads_global"), 0);
 
-  if (throttle == 0 || div <= 0) {
-    torrent::set_max_download_unchoked(m_maxDownloadsGlobal);
+  if (throttle == 0 || div == 0) {
+    torrent::set_max_download_unchoked(global);
     return;
   }
 
-  throttle /= control->variable()->get_value("max_downloads_div");
+  throttle /= rpc::call_command_value("get_max_downloads_div");
 
   unsigned int maxUnchoked;
 
@@ -201,8 +201,8 @@ Root::set_down_throttle(unsigned int throttle) {
   else
     maxUnchoked = 10 + throttle / 5;
 
-  if (m_maxDownloadsGlobal != 0)
-    torrent::set_max_download_unchoked(std::min(maxUnchoked, m_maxDownloadsGlobal));
+  if (global != 0)
+    torrent::set_max_download_unchoked(std::min(maxUnchoked, global));
   else
     torrent::set_max_download_unchoked(maxUnchoked);
 }
@@ -214,14 +214,15 @@ Root::set_up_throttle(unsigned int throttle) {
 
   torrent::set_up_throttle(throttle * 1024);
 
-  int64_t div = control->variable()->get_value("max_uploads_div");
+  unsigned int div    = std::max<int>(rpc::call_command_value("get_max_uploads_div"), 0);
+  unsigned int global = std::max<int>(rpc::call_command_value("get_max_uploads_global"), 0);
 
-  if (throttle == 0 || div <= 0) {
-    torrent::set_max_unchoked(m_maxUploadsGlobal);
+  if (throttle == 0 || div == 0) {
+    torrent::set_max_unchoked(global);
     return;
   }
 
-  throttle /= control->variable()->get_value("max_uploads_div");
+  throttle /= rpc::call_command_value("get_max_uploads_div");
 
   unsigned int maxUnchoked;
 
@@ -230,8 +231,8 @@ Root::set_up_throttle(unsigned int throttle) {
   else
     maxUnchoked = 10 + throttle / 5;
 
-  if (m_maxUploadsGlobal != 0)
-    torrent::set_max_unchoked(std::min(maxUnchoked, m_maxUploadsGlobal));
+  if (global != 0)
+    torrent::set_max_unchoked(std::min(maxUnchoked, global));
   else
     torrent::set_max_unchoked(maxUnchoked);
 }
@@ -246,26 +247,6 @@ Root::adjust_up_throttle(int throttle) {
   set_up_throttle(std::max<int>(torrent::up_throttle() / 1024 + throttle, 0));
 }
 
-void
-Root::set_max_uploads_global(int64_t slots) {
-  if (slots < 0)
-    throw torrent::input_error("Out of range.");
-
-  m_maxUploadsGlobal = slots;
-
-  set_up_throttle(torrent::up_throttle() / 1024);
-}
-
-void
-Root::set_max_downloads_global(int64_t slots) {
-  if (slots < 0)
-    throw torrent::input_error("Out of range.");
-
-  m_maxDownloadsGlobal = slots;
-
-  set_down_throttle(torrent::down_throttle() / 1024);
-}
-
 void
 Root::enable_input(const std::string& title, input::TextInput* input) {
   if (m_windowInput->input() != NULL)
